@@ -6,29 +6,34 @@
 from datetime import datetime
 from typing import Union
 
-from f1z1_common import timeunit, UnitOfTime
+from f1z1_common.src import timestamp
+from f1z1_common.src.time_ import UnitOfTime
 
 from .base import ITimeout
 
 
 class Timeout(ITimeout):
-    __slots__ = "_st", "_timeout", "_unit"
+    __slots__ = "_st", "_timeout", "_timestamp"
 
     def __init__(self,
                  int_or_float: Union[int, float],
                  unit: UnitOfTime):
         self._timeout = int_or_float
-        self._unit = unit
+        self._timestamp = timestamp(unit)
         self._st = 0
 
     def start(self) -> None:
         self._st = self._current()
 
+    @property
     def is_timeout(self) -> bool:
-        return self._current() - self._st >= self._timeout
+        return self._is_timeout()
 
     def _current(self):
-        return datetime.now().timestamp() * timeunit(self._unit)
+        return datetime.now().timestamp()
+
+    def _is_timeout(self):
+        return self._timestamp.convert(self._current() - self._st) >= self._timeout
 
     def __str__(self):
         return f"{self.__class__.__name__}(timeout={self._timeout})"
