@@ -151,7 +151,3 @@ class WorkerGroup(IWorker):
 
     def __str__(self):
         return f"{self.__class__.__name__}(workers={self._buffer.length()})"
-
-
-def is_worker(value):
-    return isinstance(value, IWorker)
